@@ -158,6 +158,49 @@ class ListAttribute(sheraf.attributes.base.BaseAttribute):
         kwargs.setdefault("default", self.persistent_type)
         super().__init__(**kwargs)
 
+    def values(self, list_):
+        """
+        By default, every items in a :class:`~sheraf.attributes.collections.ListAttribute` is indexed.
+
+        >>> class Cowboy(sheraf.Model):
+        ...     table = "cowboy"
+        ...     favorite_colors = sheraf.LargeListAttribute(
+        ...         sheraf.StringAttribute()
+        ...     ).index()
+        ...
+        >>> with sheraf.connection():
+        ...     george = Cowboy.create(favorite_colors=[
+        ...         "red", "green", "blue",
+        ...     ])
+        ...     assert george in Cowboy.search(favorite_colors="red")
+        ...     assert george in Cowboy.search(favorite_colors="blue")
+        ...     assert george not in Cowboy.search(favorite_colors="yellow")
+
+        .. warning :: A current limitation is that indexed lists won't update their
+                      indexes if they are edited through their accessor. For the indexes
+                      to be updated, the whole list must be re-assigned.
+
+        >>> with sheraf.connection():
+        ...     george.favorite_colors.append("purple")
+        ...     george in Cowboy.search(favorite_colors="purple")
+        False
+        >>> with sheraf.connection():
+        ...     george.favorite_colors = list(george.favorite_colors) + ["purple"]
+        ...     george in Cowboy.search(favorite_colors="purple")
+        True
+        """
+
+        if not self.attribute:
+            return set(list_)
+
+        return set(y for v in list_ for y in self.attribute.values(v))
+
+    def search(self, value):
+        if not self.attribute:
+            return {value}
+
+        return {v for v in self.attribute.search(value)}
+
     def deserialize(self, value):
         if not self.attribute:
             return value
@@ -490,6 +533,49 @@ class SetAttribute(sheraf.attributes.simples.TypedAttribute):
         kwargs.setdefault("default", self.persistent_type)
         super().__init__(**kwargs)
 
+    def values(self, set_):
+        """
+        By default, every items in a :class:`~sheraf.attributes.collections.SetAttribute` is indexed.
+
+        >>> class Cowboy(sheraf.Model):
+        ...     table = "cowboy"
+        ...     favorite_colors = sheraf.SetAttribute(
+        ...         sheraf.StringAttribute()
+        ...     ).index()
+        ...
+        >>> with sheraf.connection():
+        ...     george = Cowboy.create(favorite_colors={
+        ...         "red", "green", "blue",
+        ...     })
+        ...     assert george in Cowboy.search(favorite_colors="red")
+        ...     assert george in Cowboy.search(favorite_colors="blue")
+        ...     assert george not in Cowboy.search(favorite_colors="yellow")
+
+        .. warning :: A current limitation is that indexed sets won't update their
+                      indexes if they are edited through their accessor. For the indexes
+                      to be updated, the whole set must be re-assigned.
+
+        >>> with sheraf.connection():
+        ...     george.favorite_colors.add("purple")
+        ...     george in Cowboy.search(favorite_colors="purple")
+        False
+        >>> with sheraf.connection():
+        ...     george.favorite_colors = set(george.favorite_colors) | {"purple"}
+        ...     george in Cowboy.search(favorite_colors="purple")
+        True
+        """
+
+        if not self.attribute:
+            return set(set_)
+
+        return set(y for v in set_ for y in self.attribute.values(v))
+
+    def search(self, value):
+        if not self.attribute:
+            return {value}
+
+        return {v for v in self.attribute.search(value)}
+
     def deserialize(self, value):
         if not self.attribute:
             return value
