@@ -15,7 +15,11 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
 
     _indexes = None
     _primary_key = None
-    _first_instance = None
+    _is_first_instance = None
+
+    def __init__(self, *args, **kwargs):
+        self._identifier = None
+        super().__init__(*args, **kwargs)
 
     @classmethod
     def indexes(cls):
@@ -62,7 +66,7 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
         if not cls.primary_key():
             raise sheraf.exceptions.PrimaryKeyException(
                 "{} inherit from IndexedModel but has no primary key. Cannot create.".format(
-                    cls.__name__, cls.primary_key()
+                    cls.__name__
                 )
             )
 
@@ -352,33 +356,7 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
     def __setattr__(self, name, value):
         attribute = self.attributes.get(name)
         if attribute:
-            if self._first_instance is None:
-                self._first_instance = not self.index_manager().initialized()
-
-            for index in attribute.indexes.values():
-                index_manager = self.indexes()[index.key]
-                index_table_exists = index_manager.table_initialized()
-                is_indexable = self._first_instance or index_table_exists
-
-                if not is_indexable:
-                    warnings.warn(
-                        "New index in an already populated table. %s.%s will not be indexed. "
-                        'Consider calling %s.index_table_rebuild(["%s"]) to initialize the indexation table.'
-                        % (
-                            self.__class__.__name__,
-                            index.key,
-                            self.__class__.__name__,
-                            index.key,
-                        ),
-                        sheraf.exceptions.IndexationWarning,
-                        stacklevel=4,
-                    )
-                    continue
-
-                if attribute.is_created(self):
-                    index_manager.update_item(self, attribute.read(self), value)
-                else:
-                    index_manager.add_item(self, index.values_func(value))
+            self.update_attribute_indexes(attribute, value)
 
         super().__setattr__(name, value)
 
@@ -388,7 +366,46 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
         The identifier is the value of the primary_key for the current instance.
         If the primary_key is 'id', then the identifier might be an UUID.
         """
-        return getattr(self, self.primary_key())
+        if not self._identifier:
+            self._identifier = getattr(self, self.primary_key())
+
+        return self._identifier
+
+    def _is_indexable(self, index):
+        """
+        To have its entries updated, an index must have its table previously
+        initialized, with the exception of the very first model instance in
+        the database.
+        """
+        if self._is_first_instance is None:
+            self._is_first_instance = not self.index_manager().initialized()
+
+        index_manager = self.indexes()[index.key]
+        index_table_exists = index_manager.table_initialized()
+        return self._is_first_instance or index_table_exists
+
+    def update_attribute_indexes(self, attribute, value):
+        for index in attribute.indexes.values():
+            if not self._is_indexable(index):
+                warnings.warn(
+                    "New index in an already populated table. %s.%s will not be indexed. "
+                    'Consider calling %s.index_table_rebuild(["%s"]) to initialize the indexation table.'
+                    % (
+                        self.__class__.__name__,
+                        index.key,
+                        self.__class__.__name__,
+                        index.key,
+                    ),
+                    sheraf.exceptions.IndexationWarning,
+                    stacklevel=5,
+                )
+                continue
+
+            index_manager = self.indexes()[index.key]
+            if attribute.is_created(self):
+                index_manager.update_item(self, attribute.read(self), value)
+            else:
+                index_manager.add_item(self, index.values_func(value))
 
     def copy(self, **kwargs):
         r"""
@@ -471,11 +488,17 @@ class IndexedModelMetaclass(BaseModelMetaclass):
         return klass
 
 
+def model_from_table(table_name):
+    if table_name not in IndexedModelMetaclass.tables:
+        return None
+    return IndexedModelMetaclass.tables[table_name][1]
+
+
 class IndexedModel(BaseIndexedModel, metaclass=IndexedModelMetaclass):
     """
-    Top-level indexed models.
-
-    Those models are stored at the root of the database. They must
+    :class:`~sheraf.models.indexation.IndexedModel` are the top-level
+    models in the database. They come with one or several indexes,
+    stored in a *table* at the root of the database. They must
     have a **table** parameter defined and an **id** attribute.
 
     They can have a **database_name** attribute. If it is set, then in a
